import React, { useState, useEffect } from 'react'
import { Link} from 'react-router-dom';

import { get } from '../utils/request';

import {getBusStopCount, getBikeRideCount, getParkRideCount, getTrainStationCount, getTaxiCount, getTicketMachineCount, getTicketOfficeCount} from '../utils/api';

export default function Home(){

    const [sttnRry, setSttnRry] = useState([]);
    
    const [bikeRideCount, setBikeRideCount] = useState('loading...');
    const [busStopCount, setBusStopCount] = useState('loading...');
    const [parkRideCount, setParkRideCount] = useState('loading...');
    const [taxiCount, setTaxiCount] = useState('loading...');
    const [ticketMachineCount, setTicketMachineCount] = useState('loading...');
    const [ticketOfficeCount, setTicketOfficeCount] = useState('loading...');
    const [trainStationCount, setTrainStationCount] = useState('loading...');

    const fetchBikeRideCount = async () => {
        try {
	    const rsp=await getBikeRideCount();
	    setBikeRideCount((bikeRideCount) => rsp);
        } catch (err) {
            console.error('err.message: ' + err.message);
	    setBikeRideCount((bikeRideCount) => 'loading...');
        }
    };

    const fetchBusStopCount = async () => {
        try {
	    const rsp=await getBusStopCount();
	    setBusStopCount((busStopCount) => rsp);
        } catch (err) {
            console.error('err.message: ' + err.message);
	    setBusStopCount((busStopCount) => 'loading...');
        }
    };

    const fetchParkRideCount = async () => {
        try {
	    const rsp=await getParkRideCount();
	    setParkRideCount((parkRideCount) => rsp);
        } catch (err) {
            console.error('err.message: ' + err.message);
	    setParkRideCount((parkRideCount) => 'loading...');
        }
    };

    const fetchTaxiCount = async () => {
        try {
	    const rsp=await getTaxiCount();
	    setTaxiCount((taxiCount) => rsp);
        } catch (err) {
            console.error('err.message: ' + err.message);
	    setTaxiCount((taxiCount) => 'loading...');
        }
    };

    const fetchTicketMachineCount = async () => {
        try {
	    const rsp=await getTicketMachineCount();
	    setTicketMachineCount((ticketMachineCount) => rsp);
        } catch (err) {
            console.error('err.message: ' + err.message);
	    setTicketMachineCount((ticketMachineCount) => 'loading...');
        }
    };

    const fetchTicketOfficeCount = async () => {
        try {
	    const rsp=await getTicketOfficeCount();
	    setTicketOfficeCount((ticketOfficeCount) => rsp);
        } catch (err) {
            console.error('err.message: ' + err.message);
	    setTicketOfficeCount((ticketOfficeCount) => 'loading...');
        }
    };

    const fetchTrainStationCount = async () => {
        try {
	    const rsp=await getTrainStationCount();
	    setTrainStationCount((trainStationCount) => rsp);
        } catch (err) {
            console.error('err.message: ' + err.message);
	    setTrainStationCount((trainStationCount) => 'loading...');
        }
    };

    useEffect(() => {
	/*effect goes here*/
	const address = 'https://overpass-api.de/api/interpreter?data=[out:json][timeout:60];relation(4189512);map_to_area;nwr[amenity=bicycle_parking][bike_ride]["bike_ride"!="no"](area);out body center qt;';
	////console.log('StationProfile:useEffect() address: ' + address);/

	//get station array
	get(address)
	    .then(data => {
		setSttnRry((sttnRry) => data.elements);
	    });

	//fetch
	fetchBusStopCount();
	fetchBikeRideCount();
	fetchParkRideCount();
	fetchTicketMachineCount();
	fetchTicketOfficeCount();
	fetchTrainStationCount();
	fetchTaxiCount();
    }, []);

    return (
	<>
	    <p>Number of bike and ride (B&R) stations in the RVB area:&nbsp;{sttnRry.length}</p>
	    <p>Number of bike and ride (B&R) stations in the RVB area: {bikeRideCount}</p>
	    <Link
		to={'/bike-ride'}
	    >
		<button>Details for B&R Stations</button>
	    </Link>
	    <p>Number of bus stops in the RVB area: {busStopCount}</p>
	    <p>Number of park and ride (P&R) stations in the RVB area: {parkRideCount}</p>
	    <Link
		to={'/park-ride'}
	    >
		<button>Details for P&R Stations</button>
	    </Link>
	    <p>Number of taxi stations in the RVB area: {taxiCount}</p>
	    <Link
		to={'/taxi'}
	    >
		<button>Details for Taxi Stations</button>
	    </Link>
	    <p>Number of ticket machines in the RVB area: {ticketMachineCount}</p>
	    <Link
		to={'/ticket-machine'}
	    >
		<button>Details for Ticket Machines</button>
	    </Link>
	    <p>Number of ticket offices in the RVB area: {ticketOfficeCount}</p>
	    <Link
		to={'/ticket-office'}
	    >
		<button>Details for Ticket Offices</button>
	    </Link>
	    <p>Number of train stations in the RVB area: {trainStationCount}</p>
	    <Link
		to={'/train-station'}
	    >
		<button>Details for Train Stations</button>
	    </Link>
	</>
    );
}
